@@ -42,14 +42,71 @@ c'
 1 1 0
 >>> print (n+i).get_octave_notename()
 d'
+>>> i.set_from_string("u")
+>>> i.get_intvalue()
+0
+>>> i.set_from_string("au")
+>>> i.get_intvalue()
+1
+>>> i.set_from_string("m2")
+>>> i.get_intvalue()
+1
+>>> i.set_from_string("M2")
+>>> i.get_intvalue()
+2
+>>> i.set_from_string("d2")
+>>> i.get_intvalue()
+0
+>>> i.set_from_string("a2")
+>>> i.get_intvalue()
+3
+>>> i.set_from_string("d4")
+>>> i.get_intvalue()
+4
+>>> i.set_from_string("4")
+>>> i.get_intvalue()
+5
+>>> i.set_from_string("a4")
+>>> i.get_intvalue(), i.m_mod, i.m_interval, i.m_octave
+(6, 1, 3, 0)
+>>> i.set_from_string("d5")
+>>> i.get_intvalue()
+6
+>>> i.set_from_string("5")
+>>> i.get_intvalue()
+7
+>>> i.set_from_string("a5")
+>>> i.get_intvalue()
+8
+>>> i.set_from_string("d6")
+>>> i.get_intvalue()
+7
+>>> i.set_from_string("m6")
+>>> i.get_intvalue()
+8
+>>> i.set_from_string("M6")
+>>> i.get_intvalue()
+9
+>>> i.set_from_string("a6")
+>>> i.get_intvalue()
+10
+>>> i.set_from_string("d7")
+>>> i.get_intvalue()
+9
+>>> i.set_from_string("m7")
+>>> i.get_intvalue()
+10
+>>> i.set_from_string("M7")
+>>> i.get_intvalue()
+11
+>>> i.set_from_string("a7")
+>>> i.get_intvalue()
+12
 """
 if __name__ == "__main__":
-    import sys
-    sys.path.append("src")
-    import i18n
-    i18n.setup_srcdir()
+    import testsetup
 
-import string, re
+import re
 
 class Interval:
     """
@@ -80,8 +137,8 @@ class Interval:
         assert -2 <= self.m_mod <= 1 # should be increased to -3 <= x <= 2
         assert self.m_octave >= 0
         assert self.m_dir in (-1, 1)
-    def _set(self, dir, interval, mod, octave):
-        self.m_dir = dir
+    def _set(self, direction, interval, mod, octave):
+        self.m_dir = direction
         self.m_interval = interval
         self.m_mod = mod
         self.m_octave = octave
@@ -120,18 +177,15 @@ class Interval:
         decim   m10 M10
         """
         # up or down
-        s = string.strip(s)
+        s = s.strip()
         if s[0] == "-":
             self.m_dir = -1
             s = s[1:]
         else:
             self.m_dir = 1
-        # find the modifier
-        if s == 'u':
-            n, i = '', 1
         n, i = re.match("(m|M|d|a*)(\w*)", s).groups()
         if i == 'u':# u for unisone
-           i = 1
+            i = 1
         if int(i) <= 7:
             self.m_interval = int(i) - 1
             self.m_octave = 0
@@ -140,7 +194,7 @@ class Interval:
             self.m_octave = 1
         if self.m_interval in (1, 2, 5, 6):
             self.m_mod = {'d': -2, 'm': -1, 'M': 0, 'a': 1}[n]
-        elif self.m_interval in (0, 4, 5):
+        elif self.m_interval in (0, 3, 4):
             self.m_mod = {'d': -1, 'p': 0, '': 0, 'a': 1}[n]
     def get_intvalue(self):
         if __debug__:
@@ -192,5 +246,5 @@ def _test():
     import interval
     return doctest.testmod(interval)
 
-if __name__=="__main__":
+if __name__ == "__main__":
     _test()
