@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-copyright = "Copyright  1999-2006 Tom Cato Amundsen <tca@gnu.org>"
+copyright = "Copyright  1999-2005 Tom Cato Amundsen <tca@gnu.org>"
 
 import sys
 import os
@@ -152,7 +152,6 @@ import const
 import app
 from htmlwidget import HtmlWidget
 import utils
-import history
 from configwindow import ConfigWindow
 import soundcard
 import mpd
@@ -181,38 +180,8 @@ import harmonicprogressiondictation
 import singanswer
 #import example
 import learning_tree_editor
-
-class DocViewer(gtk.VBox):
-    def __init__(self, activate_cb):
-        gtk.VBox.__init__(self)
-        self.m_htmlwidget = HtmlWidget(activate_cb, self.on_anchor_track)
-        self.m_htmlwidget.show_all()
-        self.pack_start(self.m_htmlwidget)
-        self.set_size_request(500, 300)
-        self.get_vadjustment = self.m_htmlwidget.get_vadjustment
-        self.on_key_press_event = self.m_htmlwidget.on_key_press_event
-        self.m_statusbar = gtk.Statusbar()
-        self.m_statusbar.show()
-        self.pack_start(self.m_statusbar, False)
-        self.source = self.m_htmlwidget.source
-        self.grab_focus = self.m_htmlwidget.grab_focus
-    def read_docfile(self, fn, anchor):
-        """
-        We reread the docfile even if we are alreado displaying this file,
-        just in case it has changed on disk.
-        """
-        if fn:
-            self.m_htmlwidget.read_docfile(fn)
-        if anchor and 'g_view' in dir(self.m_htmlwidget):
-            self.m_htmlwidget.g_view.jump_to_anchor(anchor)
-    def on_anchor_track(self, url):
-        if url:
-            # remove newlines in url because it make the window resize
-            s = url.replace("\n", "")
-            self.m_statusbar.pop(1)
-            self.m_statusbar.push(1, s)
-        else:
-            self.m_statusbar.pop(1)
+from docviewer import DocViewer
+from helpbrowser import HelpBrowser
 
 class ResolveLessonIdCrashDlg(gtk.Dialog):
     def __init__(self, lessonfile_manager, lesson_id):
@@ -278,6 +247,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         self.connect('destroy', self.quit_program)
         self.connect('key_press_event', self.on_key_press_event)
         self.g_about_window = None
+        self.g_help_browser = None
         self.g_learning_tree_editor = None
         self.main_box = gtk.VBox()
         self.main_box.show()
@@ -287,10 +257,6 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         self.box_dict = {}
         self.g_config_window = None
         self.g_musicviewer_window = None
-        self.m_history = history.History()
-        self.m_key_bindings = {'history_back_ak': self.history_back,
-                               'history_forward_ak': self.history_forward,
-                               'history_reload_ak': self.history_reload}
         self.m_app = app.SolfegeApp(options, self, lessonfile_manager)
         self.g_ui_manager = gtk.UIManager()
         self.m_action_groups = {
@@ -301,7 +267,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         for a in self.m_action_groups.values():
             self.g_ui_manager.insert_action_group(a, 1)
         self.setup_menu()
-        self.m_app.handle_href('welcome.html')
+        self.display_docfile_in_mainwin('welcome.html')
     def change_learning_tree(self, tree_fn):
         """
         Change to a different learning tree.
@@ -350,8 +316,8 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
           ('HelpMenu', None, _('_Help')),
           ('HelpHelp', 'gtk-help', _('_Help on current exercise'), 'F1', None,
             lambda o: self.m_app.please_help_me()),
-          ('HelpIndex', None, _('_All help files'), None, None,
-            lambda o: self.m_app.handle_href('toc.html')),
+          ('HelpIndex', None, _('_User manual'), None, None,
+            lambda o: self.m_app.handle_href('index.html')),
           ('HelpAllLessonFiles', None, _('All installed _lesson files'), None,
             None, lambda o: self.m_app.handle_href('solfege:all-lessonfiles')),
           ('HelpCopyright', None, _('_Copyright notice'), None, None,
@@ -367,8 +333,6 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
            lambda w: self.box_dict['docviewer'].m_htmlwidget.g_view.zoom_out()),
           ('ViewZoom100', 'gtk-zoom-100', _('Help viewer zoom reset'), '<ctrl>equal', None,
            lambda w: self.box_dict['docviewer'].m_htmlwidget.g_view.zoom_reset()),
-          ('BrowserGoBack', 'gtk-go-back', None, None, None, self.history_back),
-          ('BrowserGoForward', 'gtk-go-forward', None, None, None, self.history_forward),
           ('ShowBugReports', None, _('See your bug reports'), None, None,
             self.show_bug_reports),
         ])
@@ -634,15 +598,10 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
                    ['practise', 'config', 'statistics'].index(urlobj.action))
             else:
                 self.box_dict[self.m_viewer].g_notebook.set_current_page(0)
-        if self.box_dict[module].m_t.m_P:
-            if isinstance(self.box_dict[module].m_t, abstract.LessonbasedTeacher):
-                self.set_title("Solfege - " + self.box_dict[module].m_t.m_P.header.title)
-            else:
-                self.set_title("Solfege - " + self.box_dict[module].m_t.exercise_data['name'].replace("_", ""))
+        if isinstance(self.box_dict[module].m_t, abstract.LessonbasedTeacher):
+            self.set_title("Solfege - " + self.box_dict[module].m_t.m_P.header.title)
         else:
-            self.set_title("Solfege")
-        #self.m_history.add(urlobj.href)
-        #self.show_help_on_current()
+            self.set_title("Solfege - " + self.box_dict[module].m_t.exercise_data['name'].replace("_", ""))
     def _show_docviewer(self):
         if 'docviewer' not in self.box_dict:
             self.box_dict['docviewer'] = DocViewer(self.m_app.handle_href)
@@ -652,39 +611,18 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         self.m_viewer = 'docviewer'
         self.box_dict['docviewer'].show()
     def display_docfile(self, fn, anchor):
+        if not self.g_help_browser:
+            self.g_help_browser = HelpBrowser(self.m_app)
+        self.g_help_browser.show()
+        self.g_help_browser.present()
+        self.g_help_browser.show_docfile(fn, anchor)
+    def display_docfile_in_mainwin(self, fn, anchor=None):
         self._show_docviewer()
         self.box_dict['docviewer'].read_docfile(fn, anchor)
         self.set_title("Solfege - %s" % fn)
-        self.m_history.add(fn)
-    def display_html(self, html):
+    def display_html(self, html):#FIXME do in helpbrowser
         self._show_docviewer()
         self.box_dict['docviewer'].source(html)
-    def history_back(self, *v):
-        #if self.m_viewer == 'docviewer':
-        #    self.m_history.set_adj_of_current(
-        #      self.box_dict['docviewer'].get_vadjustment().get_value())
-        self.m_history.back()
-        self.m_history.lock()
-        url, adj = self.m_history.get_current()
-        self.m_app.handle_href(url, display_docfile_set_adj=0)
-        #if self.m_viewer == 'docviewer':
-        #    self.box_dict['docviewer'].get_vadjustment().set_value(adj)
-        self.m_history.unlock()
-    def history_forward(self, *v):
-        #if self.m_viewer == 'docviewer':
-        #    self.m_history.set_adj_of_current(
-        #      self.box_dict['docviewer'].get_vadjustment().get_value())
-        self.m_history.forward()
-        self.m_history.lock()
-        url, adj = self.m_history.get_current()
-        self.m_app.handle_href(url, display_docfile_set_adj=0)
-        #if self.m_viewer == 'docviewer':
-        #    self.box_dict['docviewer'].get_vadjustment().set_value(adj)
-        #self.m_history.unlock()
-    def history_reload(self, *v):
-        self.m_history.lock()
-        self.m_app.handle_href(self.m_history.get_current()[0])
-        self.m_history.unlock()
     def initialise_exercise(self, teacher):
         """
         Create a Gui object for the exercise and add it to
@@ -699,12 +637,6 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         self.box_dict[n].show()
         self.m_viewer = n
     def on_key_press_event(self, widget, event):
-        if event.type == gtk.gdk.KEY_PRESS:
-            for s in self.m_key_bindings:
-                if (event.state & (gtk.gdk.CONTROL_MASK|gtk.gdk.SHIFT_MASK|gtk.gdk.MOD1_MASK), event.keyval) \
-                         == utils.parse_key_string(self.get_string(s)):
-                    self.m_key_bindings[s]()
-                    return 1
         self.box_dict[self.m_viewer].on_key_press_event(widget, event)
     def open_preferences_window(self, widget=None):
         if not self.g_config_window:
